#
# spec file for package powerdevil5
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           powerdevil5
Version:        5.27.9
Release:        bp155.2.3.1
# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.8.95 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        KDE Power Management module
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/powerdevil-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/powerdevil-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  extra-cmake-modules >= 5.102
BuildRequires:  kf5-filesystem
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  cmake(KF5Activities)
BuildRequires:  cmake(KF5Auth)
BuildRequires:  cmake(KF5BluezQt)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5GlobalAccel)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IdleTime)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5NotifyConfig)
BuildRequires:  cmake(KF5Screen) >= %{_plasma5_version}
BuildRequires:  cmake(KF5Solid)
#!BuildIgnore:  kwin5
BuildRequires:  cmake(LibKWorkspace) >= %{_plasma5_version}
BuildRequires:  cmake(Qt5DBus) >= 5.15.2
BuildRequires:  cmake(Qt5Widgets) >= 5.15.2
BuildRequires:  cmake(Qt5X11Extras) >= 5.15.2
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-dpms)
BuildRequires:  pkgconfig(xcb-randr)
#PrepareForSleep is added to systemd 198, and with Plasma 5.2, will be unconditionaly called
Requires:       systemd >= 198
%requires_ge plasma5-workspace-libs
Recommends:     %{name}-lang
Conflicts:      kdebase4-workspace < 5.3.0
# Needed for battery / brightness detection
Recommends:     upower
# For switching power profiles
Recommends:     power-profiles-daemon

%description
KDE Power Management module. Provides kded daemon,
DBus helper and KCM for configuring Power settings.

%lang_package

%prep
%autosetup -p1 -n powerdevil-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
%cmake_build

%install
%kf5_makeinstall -C build

%kf5_find_lang
%kf5_find_htmldocs

rm -rv %{buildroot}%{_kf5_libdir}/libpowerdevil{ui,core,configcommonprivate}.so

%post
/sbin/ldconfig
%{systemd_user_post plasma-powerdevil.service}

%preun
%{systemd_user_preun plasma-powerdevil.service}

%postun
/sbin/ldconfig
%{systemd_user_postun plasma-powerdevil.service}

%files
%license COPYING*
%{_kf5_applicationsdir}/kcm_powerdevilactivitiesconfig.desktop
%{_kf5_applicationsdir}/kcm_powerdevilglobalconfig.desktop
%{_kf5_applicationsdir}/kcm_powerdevilprofilesconfig.desktop
%{_kf5_debugdir}/powerdevil.categories
%{_kf5_libdir}/libpowerdevilconfigcommonprivate.so.*
%{_kf5_libdir}/libpowerdevilcore.so.*
%{_kf5_libdir}/libpowerdevilui.so.*
%doc %{_kf5_htmldir}/en
%dir %{_kf5_plugindir}/kf5/
%dir %{_kf5_plugindir}/powerdevil/
%dir %{_kf5_plugindir}/powerdevil/action
%dir %{_kf5_plugindir}/kf5/powerdevil/
%dir %{_kf5_plugindir}/plasma
%dir %{_kf5_plugindir}/plasma/kcms/
%dir %{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_powerdevilactivitiesconfig.so
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_powerdevilglobalconfig.so
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_powerdevilprofilesconfig.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_brightnesscontrolaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_dimdisplayaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_dpmsaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_handlebuttoneventsaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_keyboardbrightnesscontrolaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_powerprofileaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_runscriptaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_suspendsessionaction.so
%{_kf5_plugindir}/powerdevil/action/powerdevil_wirelesspowersavingaction.so
%{_kf5_plugindir}/kf5/powerdevil/powerdevilupowerbackend.so
%{_kf5_plugindir}/powerdevilbrightnesscontrolaction_config.so
%{_kf5_plugindir}/powerdevildimdisplayaction_config.so
%{_kf5_plugindir}/powerdevildpmsaction_config.so
%{_kf5_plugindir}/powerdevilhandlebuttoneventsaction_config.so
%{_kf5_plugindir}/powerdevilkeyboardbrightnesscontrolaction_config.so
%{_kf5_plugindir}/powerdevilrunscriptaction_config.so
%{_kf5_plugindir}/powerdevilpowerprofileaction_config.so
%{_kf5_plugindir}/powerdevilsuspendsessionaction_config.so
%{_kf5_plugindir}/powerdevilwirelesspowersavingaction_config.so
%{_kf5_notifydir}/
%{_kf5_sharedir}/dbus-1/system-services/org.kde.powerdevil.backlighthelper.service
%{_kf5_dbuspolicydir}/org.kde.powerdevil.backlighthelper.conf
%{_kf5_sharedir}/polkit-1/actions/org.kde.powerdevil.backlighthelper.policy
%{_kf5_sharedir}/dbus-1/system-services/org.kde.powerdevil.discretegpuhelper.service
%{_kf5_dbuspolicydir}/org.kde.powerdevil.discretegpuhelper.conf
%{_kf5_sharedir}/polkit-1/actions/org.kde.powerdevil.discretegpuhelper.policy
%{_kf5_sharedir}/dbus-1/system-services/org.kde.powerdevil.chargethresholdhelper.service
%{_kf5_sharedir}/dbus-1/system.d/org.kde.powerdevil.chargethresholdhelper.conf
%{_kf5_sharedir}/polkit-1/actions/org.kde.powerdevil.chargethresholdhelper.policy
%{_libexecdir}/kauth/
%{_libexecdir}/org_kde_powerdevil
%{_userunitdir}/plasma-powerdevil.service

%{_kf5_configdir}/autostart/powerdevil.desktop

%files lang -f %{name}.lang

%changelog
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- Changes since 5.27.8:
  * Provide a default action in Suspend session config (kde#475866)
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- Changes since 5.27.7:
  * profiledefaults: don't automatically suspend by default if running in a virtual machine
  * Fix the error overlay shown on other kcms (kde#424531)
  * dimdisplay: only dim the screen at configured dim time (kde#304696)
  * Print error with higher logging severity when backend fails to load
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- No code changes since 5.27.6
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- Changes since 5.27.5:
  * Fix ddcutil for laptop user (kde#469895)
  * Take property update frequency into account for smoothed remaining time
  * Delay Solid::Battery instatiation until actually required
  * Avoid repeated Solid::Battery instantiations on charge level change
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- Changes since 5.27.4:
  * Fix for screen backlight not working on Planet Computers Astro Slide PDA
  * Fix and consolidate discharge rate and remaining time calculation
  * Remove unused "BatteryState" from backend interface
  * Fix possible race between DeviceAdded signal and device enumeration
  * Remove support for UPower < 0.99.0
* Wed Apr 19 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup build dependencies:
  * Remove unused KDELibs4Support and KF5Wayland
  * Explicitly add KF5Crash, KF5DocTools and KF5Notifications
  * Update required versions.
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- Changes since 5.27.2:
  * Suspend by default on AC profile
  * Use correct tablet mode function to determine mobile-ness
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- Changes since 5.27.1:
  * cmake: Fix capitalisation in the find_package_handle_standard_args() call
  * ddc: Fix cleaning up handles when we are redetecting screens
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- Changes since 5.27.0:
  * Only skip batteries if neither start or stop thresholds are available (kde#464535)
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- Changes since 5.26.90:
  * chargethresholdhelper: Filter out batteries without thresholds early (kde#464535)
  * daemon: Fix wakeup removal not rescheduling the timerfd wakeup BUG: 464251 (kde#464251)
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * Handle Button Events: Turn off keyboard backlight when lid is closed (kde#444029)
  * Do not hardcode ACPI battery names
  * Use ecm_set_disabled_deprecation_versions
  * Remove unused KWayland dep
  * Remove out-of-date infor from kcm docbook
  * Apply exponential moving average to remaining time when unplugged
  * powerdevilbackendinterface: run clang-format
  * Better libddcutil error handling
  * Install translated documentation from po/ too
  * Allow triggering critical battery action manually
  * Choose easing curve based on old and new brightness values
  * wirelesspowersaving: Reduce calls to NetworkManager::permissions()
  * DPMS: Port to KScreenDPMS
  * powerprofileconfig: Use proper signal for detecting user interaction
  * Add FreeBSD Qt6 CI
  * Add Linux Qt6 CI
  * Fix install in kf6/
  * Perform initialization in initialization list
  * Fix compile against qt6
  * Install po folder
  * Set bugReportURL for KCMs
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- Changes since 5.26.4:
  * Do not hardcode ACPI battery names
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- Changes since 5.26.3:
  * Install translated documentation from po/ too
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- Changes since 5.26.2:
  * powerprofileconfig: Use proper signal for detecting user interaction
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * Install po folder
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Match argument in calculateNextStep
  * Cleanup peripheral battery notifications
  * Fix profile switching in the brightness actions (kde#394945)
  * Add missing license file
  * Remove 'advanced users only' from settings description
  * Remove no longer needed ifdefs
  * Port away from deprecated Kirigami include
  * Remove service type definition
  * Clenaup some leftovers in CMakeLists
  * powerdevilactionpool: Avoid double quering of plugin namespace
  * Remove no longer needed X-KDE-PowerDevil-Action-IsBundled property
  * Port away KServiceTypeTrader and use plugin system
  * Clean up some uneeded values from KCM json files
  * Convert  desktop files of KCMs to JSON
  * Add wording for when battery gets low while it is charged
  * Update battery notifications if they remain open
  * When battery drains, show a notification even when AC is plugged in
  * Port KCMs to new plasma install namespaces, embed json metadata
  * upower: Prevent integer overflow during new brightness computation (kde#454161)
  * Request passing unit tests on Linux and BSD
  * Make "charge thresholds not supported" error message more explicit
  * Use cmakedefine01
  * Add missing include
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- Changes since 5.25.4:
  * Fix profile switching in the brightness actions (kde#394945)
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- Changes since 5.25.3:
  * Update battery notifications if they remain open
  * When battery drains, show a notification even when AC is plugged in
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- Changes since 5.25.0:
  * upower: Prevent integer overflow during new brightness computation (kde#454161)
- Drop patches, now upstream:
  * upower-Prevent-integer-overflow-during-new-brightness.patch
* Fri Jun 17 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Add backported upower-Prevent-integer-overflow-during-new-brightness.patch
  * Fixes brightness stuck on low level on systems with multiple GPUS
    ( boo#1199907 kde#454161 )
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- No code changes since 5.24.90
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * daemon/actions: remove unused variable
  * Remove unused KRun code
  * Use non-deprecated KAuth includes
  * Deduce pair types automatically
  * Remove unused includes
  * Adapt to QtX11Extras being gone in Qt6
  * Use version-less install dir variables
  * Port away from QStringRef
  * Fix Commit 761fc8a4
  * Add percentage display next to the brightness and keyboard backlight sliders in KCM (kde#440314)
  * Adapt build system for building against qt6 (need kscreen not ported yet)
  * Write brightness to all raw devices (kde#399646)
  * Fix signature in qt6
  * Use new kauth includes
  * Improved backlight devices selection (kde#399646)
  * Support hardware with only one charging threshold, not both (kde#449997)
  * Use not deprecated SYSTEMD_USER_UNIT_INSTALL_DIR
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- Changes since 5.24.2:
  * Improved backlight devices selection (kde#399646)
- Restore compatibility with older kf5-filesystem
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%_libdir/libexec with %%_libexecdir (boo#1174075)
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- Changes since 5.24.0:
  * Support hardware with only one charging threshold, not both (kde#449997)
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- No code changes since 5.23.90
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * powerprofileconfig: Use m_profileCombo as the watcher's parent
  * Restore connect to powerOffButtonTriggered
  * backlighthelper: fix brightness handling for embedded devices
  * Fix some clazy warning
  * Support new charge_control_*_threshold
  * Check if backlight device is enabled (kde#399646)
  * Add GitLab CI
  * powerdevilcore: Add some context to debug output
  * Bluez and NM are Linux only dependencies
  * Port deprecated KCModule constructor
  * Use KWin's tablet mode to decide on the mobility UX
  * Always dismiss critical battery notification (kde#445171)
  * We depend against qt5.15
  * A few code cleanups
  * UPowerBackend: remove dead code
  * dpms: don't lock until dimmed
  * Add .kde-ci.yml
  * Clear alwaysActionBox before filling (kde#443114)
  * On FreeBSD do not try to execute powerdevil.backlighthelper.syspath action.
  * Remove inappropriate low maximum width for spinboxes (kde#442556)
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- Changes since 5.23.4:
  * powerprofileconfig: Use m_profileCombo as the watcher's parent
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- Changes since 5.23.3:
  * Always dismiss critical battery notification (kde#445171)
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- Changes since 5.23.2:
  * On FreeBSD do not try to execute powerdevil.backlighthelper.syspath action.
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * Clear alwaysActionBox before filling (kde#443114)
  * Remove inappropriate low maximum width for spinboxes (kde#442556)
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * Add keywords to power KCMs
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * powerprofiles: Add support for ProfileHolds
  * powerprofiles: expose PerformanceDegraded property
  * Fix crash if dbus call finishes before we have a valid config group (kde#440338)
  * Handle DBus call finishing before buildUI is called (kde#440223)
  * Integrate power-profiles daemon
  * Use version-less qt DBus macros
  * Use ellipses instead of triple period
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- No code changes since 5.21.90
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Changes since 5.21.5:
  * GetSessionByPID DBUS call always fails on newer systemd versions (kde#433408)
  * Bundle the DPMS action
  * Require C++17
  * Port connects to the new format
  * Raise minimum CMake version to 3.16
  * Move upower backend cmake code to subfolder
  * Remove powerdevil core versioning
  * core: when we get request to wakeup turn dpms on
  * [kcm] Add a few more relevant keywords (kde#432776)
  * Use FindUDev from ECM
  * [backlighthelper] Don't touch brightness when animation isn't running
  * Use versionless Qt cmake target
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- No code changes since 5.21.3
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- No code changes since 5.21.2
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- Changes since 5.21.0:
  * core: when we get request to wakeup turn dpms on
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * [backlighthelper] Don't touch brightness when animation isn't running
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Changes since 5.20.5:
  * Autogenerate categories file
  * Clarify ambiguous settings entries in launchers
  * Clear ambiguity when searching for settings in launchers
  * Take into account logind sleep and idle inhibitions (kde#364067)
  * mobile: bind the power off key to "Turn Off Screen"
  * Expose screen locked state in policy agent
  * autostart: start powerdevil earlier in the phase 0
  * Set NoDisplay=true in powerdevil autoatart
  * Remove use of XCB DPMS timeouts and handle it explicitly
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Do not explicitely define Exec lines for KCMs
  * Add gitignore file
  * Ignore player's from KDE Connect when suspending (kde#427209)
  * Remove XRandRBrightness
  * Honor animation brightness threshold also for sysfs helper (kde#426883)
  * Add systemd unit for powerdevil
  * Set correct type for autostart .desktop file
  * Show "you might need to reconnect charger" hint only when charging/fully charged
  * Take DESTDIR into account when running setcap
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- No code changes since 5.20.3
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- No code changes since 5.20.2
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- Changes since 5.20.0:
  * Ignore player's from KDE Connect when suspending (kde#427209)
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- Changes since 5.19.90:
  * Show "you might need to reconnect charger" hint only when charging/fully charged
  * Take DESTDIR into account when running setcap
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Changes since 5.19.5:
  * Remove explicit ECM_KDE_MODULE_DIR
  * Add setting for charge threshold
  * Remove shortcut migration code
  * [core] Return early if no wakeup was cleared
  * [core] send the dbus error if wakeup is invalid
  * cmake: set the CAP_WAKE_ALARM capability on the powerdevil
  * [core] introduce the method to wake system up
  * Set min width of activities KCM to smaller value (kde#407622)
  * On wakeup from suspend restore remembered keyboard brightness
  * [mobile] on mobile devices lock screen before we turn it off
  * [mobile] various adjustments related to power management
  * [dpms action] introduce option to lock screen before turning off
  * Use camelcase (scripted)
  * [kcm] Remove incorrect information from error message (kde#423872)
  * Fix compilation with ddcutil 0.9.9
  * Play sound when plugged in
  * Change "adaptor" to "adapter"
  * Fix build on FreeBSD
  * WIP: Implement smooth brightness change for sysfs / backlight helper
  * Use add_definitions instead of add_compile_definitions
  * Add a logging category config file
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- Changes since 5.19.4:
  * On wakeup from suspend restore remembered keyboard brightness
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- Changes since 5.19.3:
  * Split args in RunScript again
- Drop patches, now upstream:
  * 0001-Split-args-in-RunScript-again.patch
* Thu Jul 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to restore behaviour of RunScript (boo#1173763):
  * 0001-Split-args-in-RunScript-again.patch
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- Changes since 5.19.2.1:
  * Fix compilation with Qt 5.15, this hit the time bomb too
* Tue Jun 23 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.19.2.1
  * Watch DBus service right away to discard pending inhibitions
    reliably (kde#423131)
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- No code changes since 5.19.1
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- No code changes since 5.19.0
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- No code changes since 5.18.90
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * Close low battery notificaton when showing critical
  * Make low battery notification critical
  * bump to require Qt 5.14
  * Properly store the powerdown action
  * Improve powerdevil's main
  * Revert "Fix build with Qt 5.15"
  * Fix compilation with Qt 5.15, this hit the time bomb too
  * Include comment for translators for Power Down
  * Port deprecated method
  * Fix build with Qt 5.15
  * Improve the behaviour of the power button on mobile
  * replace Q_FOREACH with for-range loop, should fix freeBSD compilation
  * Use directly a QMultiHash here, as it used insertMulti
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- No code changes since 5.18.4.1
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- No code changes since 5.18.2
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- Changes since 5.18.1:
  * Fix compilation with Qt 5.15, this hit the time bomb too
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- Changes since 5.18.0:
  * Prevent powerdevil from calling DPMS extension calls when DPMS extension isn't present
  * fix FreeBSD compilation, Q_FOREACH -> for-range loop
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- No code changes since 5.17.90
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * KF5_MIN_VERSION for plasma 5.18 is KF5 5.66.0
  * Drop unused method
  * Use URLs with transport encryption
  * Show peripheral low battery notification for NoCharge
  * Add specialized notification for Bluetooth battery
  * Lock screen by default, on mobile
  * Add Q_ENUM to enums for happier debugging
  * Port to std::sort
  * Remove unused include
  * Make it compiles without deprecated methods
  * Add KDEClangFormat cmake support
  * Fix minor typos
  * Port away from foreach
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- Changes since 5.17.4:
  * Check for DPMS extension being present (kde#414921)
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- No code changes since 5.17.0
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Changes since 5.16.5:
  * update to latest kf5 dependency
  * It can be build without deprecated method
  * Add a global shortcut action to turn off the screen
  * Added new Suspend then Hibernate option
  * Fix forward declaration
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- No code changes since 5.16.4
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- No code changes since 5.16.2
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- Changes since 5.16.1:
  * [powerdevil] Return battery source monitoring
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- Changes since 5.16.0:
  * Ignore power management inhibition in battery critical timeout (kde#408398)
* Thu Jun 13 2019 Fabian Vogt <fabian@ritter-vogt.de>
- File moved to %%_kf5_dbuspolicydir
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- Changes since 5.15.90:
  * Set application name to org_kde_powerdevil (kde#407721)
- Drop patches, fixed upstream:
  * 0001-Revert-Add-KAboutData.patch
* Mon May 20 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix reading of global shortcuts (kde#407721):
  * 0001-Revert-Add-KAboutData.patch
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
  * Move files to their correct place
  * DDCUtil: Improved DDCUtil support for brightness control over DDC/CI channel for supported monitors
  * Set Critical urgency for battery... critical notification
  * Remove critical error notification
  * Fixed initial size and content width of Activity Settings KCM (kde#398793)
  * [powerdevil] Touch up messages/prompts
  * [powerdevil] Correct labels
  * Fix one last instance of the word "Suspend" in the UI
  * [KCM & UI] Use the word "Sleep" instead of "Suspend"
  * Add KAboutData
  * Use the new KAuthCore
  * Change icon for Activities config
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- No code changes since 5.15.4
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- No code changes since 5.15.3
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- Changes since 5.15.2:
  * Fix crash when mutating a container while iterating it (kde#403776)
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- Changes since 5.15.0:
  * Exclude powerdevil from session management
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- No code changes since 5.14.90
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * bump KF5 dependency to required 5.54 as agreed at start of Plasma 5.15 cycle
  * [dimdisplay] Waits a bit display to wake-up
  * [dimdisplay] Do not change screen brightness on invalid values
  * KCModule general page: Change conditional to what was probably intended
  * Avoid creation of needless temporary containers
  * Add missing emit keyword
  * Add some QStringLiteral
  * qt5.11 uses gcc 4.8 as minimum version
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * [dimdisplay] Do not change screen brightness on invalid values
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- No code changes since 5.14.3
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Changes since 5.13.90:
  * Revert "Remove XRandrBrightness" (kde#399018)
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * Remove XRandrBrightness
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Remove wrong & unused X-KDE-DBus-ModuleName entry from daemon app metadata
  * Display brightness OSD even when min and max is reached (kde#387284)
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Revert "Revert "Get rid of KDELibs4Support""
  * org.freedesktop.PowerManagement.Inhibit should only prevent suspend
  * Use platform detection from KWorkspace in Powerdevil
  * Remove outdated condition for calling feature_summary()
  * Use non-deprecated KDEInstallDirs variables
  * Update D-Bus xml file to use "Out*" for signal type Qt annotations
  * End source files with newline
  * Fix typos in comments
  * Use override
  * Use nullptr
  * Use explicit
  * Remove Qt module include
  * Remove module prefixes from Qt includes
  * Remove unneeded moc includes
  * Remove duplicated add_definitions(-DQT_NO_KEYWORDS)
  * Remove unneeded cmake macro include
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Require KDE Frameworks 5.42 and Qt 5.9
  * Bump min cmake version to 3.0, move cmake_minimum_required to begin
  * Properly define an optional feature, i.e. ddcutils
- Remove patches, now upstream:
  * 0001-Use-platform-detection-from-KWorkspace-in-Powerdevil.patch
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * Ignore "migration" key for determining whether the config is empty (kde#391782)
- Remove patches, now upstream:
  * 0001-Ignore-migration-key-for-determining-whether-the-con.patch
* Thu Apr 26 2018 fabian@ritter-vogt.de
- Add patch to fix initial config generation (kde#391782):
  * 0001-Ignore-migration-key-for-determining-whether-the-con.patch
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Sat Mar 24 2018 fabian@ritter-vogt.de
- Add patch to support wayland sessions without QT_QPA_PLATFORM:
  * 0001-Use-platform-detection-from-KWorkspace-in-Powerdevil.patch
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * Add explicit includes to fix build with Qt 5.11
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * Fix PowerDevil shortcuts migration (kde#389991)
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * None
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Only send low peripheral battery notification when in discharging state
  * Remove obsolete reviewboardrc file
  * Migrate powerdevil keyboard shortcuts
  * Prefer an algorithm over an explicit for loop
  * Fix brightness not restoring when an inhibition is active (kde#352497)
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Mon Oct 30 2017 lbeltrame@kde.org
- Recommend upower, to ensure it is installed for battery
  and brightness detection (boo#1065650, boo#1065642)
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Sat Oct 21 2017 fabian@ritter-vogt.de
- Add #!BuildIgnore to break the
  plasma5-workspace-devel -> plasma5-workspace -> kwin5 -> kdialog
  dep chain which results in pulling in kdebase4-runtime on 42.2
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * Disable DDCUtil by default
  * Bump the version requirement for Qt
  * Revert "skip the disabled backlight device" (kde#381114,kde#381199)
  * Use Q_DECL_OVERRIDE
  * cmake: link to ddcutil only if found
  * Add brightness control using ddcutil lib
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * Revert "skip the disabled backlight device" (kde#381114,kde#381199)
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * None
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * Fix the skip disabled backlight device
  * Pause media players on suspend
  * Re-trigger lid action when lid is closed and external monitor is disconnected (kde#379265)
  * Revert "Get rid of KDELibs4Support"
  * skip the disabled backlight device
  * Remove no longer needed config-workspace header
  * Get rid of KDELibs4Support
  * Get rid of QWeakPointer
  * Add UI for hybrid suspend mode
  * rename wireless power saving to wireless
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * None
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * None
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * None
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * Add missing 'Hibernate'.
  * Add information about existence of discrete GPU.
  * No need to have a KGlobalAccel instance to call setGlobalShortcut.
  * Explain re-triggering lid close on profile change.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Thu Nov  3 2016 fabian@ritter-vogt.de
- Introduce new _plasma5_bugfix global for more fine-tuned dependencies
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Use %%{_plasma5_version} again, define it if needed
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
- Drop old_action_names.patch, not needed
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
- Only conflict with kdebase4-workspace < 5.3.0
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Added libkscreen2-devel BuildRequires
- Drop pkgconfig(x11) and pkgconfig(xrandr) BuildRequires
- Drop activityConfig.patch, merged upstream
- Added old_action_names.patch, until we have newer polkit-default-privs
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
- Drop patches merged upstream:
  0005-Fix-default-critical-action.patch,
  0003-prepare-for-kernel-4.0.patch and
  0006-Change-default-low-battery-threshold-to-10.patch
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Add explicit kdbusaddons-devel BuildRequires
* Fri Mar 13 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0003-prepare-for-kernel-4.0.patch,
  0005-Fix-default-critical-action.patch (kde#344905),
  0006-Change-default-low-battery-threshold-to-10.patch and
  activityConfig.patch (restores the ability to configure
  activity-specific power management settings)
- Added kactivities5-devel BuildRequires, per activityConfig.patch
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
- Drop 0001-Fix-PowerDevil-brightness-calls-breaking-kded-Volume.patch,
  merged upstream
* Fri Jan 30 2015 hrvoje.senjan@gmail.com
- Added 0001-Fix-PowerDevil-brightness-calls-breaking-kded-Volume.patch
  (kde#337674)
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Require systemd >= 198
- Harden plasma5-workspace-libs Requires
- Drop 0001-Fix-battery-remaining-time-update-with-upower-0.99.patch,
  merged upstream
* Fri Dec  5 2014 hrvoje.senjan@gmail.com
- Added 0001-Fix-battery-remaining-time-update-with-upower-0.99.patch,
  kde#339957
* Sat Oct 25 2014 hrvoje.senjan@gmail.com
- Recommend lang subpackage
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.2:
  Fixed kde#335466
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Fri Aug  8 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Thu Jul 24 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1~20140724~48b5011 snapshot
- Drop kauth_fixups.patch and soversion.diff, merged upstream
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Fri Jun  6 2014 hrvoje.senjan@gmail.com
- Activate powerdevil5 package
